Gestione utenti — SoL 4, manuale utente

# Gestione utenti

Per interagire con il sistema, cioè per poter inserire nuovi tornei e altre entità, si devono inserire per proprie credenziali nel pannello di login. Tali credenziali possono essere fornite dall'amministratore, oppure ottenute tramite l'auto registrazione.

Indice

- Gestione utenti

  - Voci del menu

  - Inserimento e modifica

    - Email e password

    - Nome e cognome

    - Lingua

    - Gestione responsabilità

    - Gestione giocatori

    - Stato

## Voci del menu

Oltre alle azioni standard il menu contiene queste voci:

Club

  Apre la gestione dei club di cui è responsabile l'utente selezionato

Campionati

  Apre la gestione dei campionati di cui è responsabile l'utente selezionato

Giocatori

  Apre la gestione dei giocatori di cui è responsabile l'utente selezionato

Valutazioni

  Apre la gestione delle valutazioni di cui è responsabile l'utente selezionato

Tornei

  Apre la gestione dei tornei di cui è responsabile l'utente selezionato

## Inserimento e modifica

Tutti i campi, ad eccezione della lingua, sono obbligatori.

### Email e password

Queste sono le credenziali che l'utente dovrà inserire nel pannello di login. email deve essere un indirizzo valido e la password può essere qualunque cosa più lunga di cinque caratteri.

Nota

Mentre la procedura di auto registrazione accerta la validità dell'indirizzo email, quando questo viene inserito o modificato manualmente non viene effettuata alcuna verifica che l'indirizzo corrisponda a una casella di posta esistente. Si raccomanda pertanto di prestare particolare attenzione: un valore sbagliato preclude la possibilità di poter reimpostare la propria password nel caso venisse dimenticata!

### Nome e cognome

Non possono essere lasciati in bianco.

### Lingua

Se impostata, verrà usata a prescindere dalle impostazioni del browser quando l'utente accede al sistema.

### Gestione responsabilità

L'amministratore può dare il permesso di gestione responsabilità a particolari utenti: quando un utente ha questo permesso è in grado di modificare chi è il responsabile degli altri elementi (club, tornei, ...), anche di quelli che non gli appartengono.

### Gestione giocatori

L'amministratore può dare il permesso di gestione giocatori a particolari utenti: quando un utente ha questo permesso è in grado di inserire nuovi giocatori, o modificare e cancellare quelli già presenti.

Nota

Permettere a chiunque di gestire l'elenco dei giocatori, come accadeva nelle versioni di SoL precedenti alla 4, ha causato numerosi problemi, in primis la presenza di duplicati: un po' per pigrizia, un po' per difficoltà linguistiche, è chiaramente più sbrigativo reinserire un giocatore che si presenta a un torneo che verificare se sia già presente nel database.

Risolvere questi casi non è sempre facile, quando non si conoscono di persona.

Con la versione 4 si è deciso di poter dare la possibilità di gestire i giocatori solo a un ben determinato gruppo di utenti: in linea di principio vi saranno dei responsabili riconosciuti, ragionevolmente uno per ogni nazione, mirando in tal modo a far inserire e modificare i dati dei singoli giocatori a chi li conosce e può identificarli.

### Stato

Lo stato corrente dell'utente:

Registrato

  la procedura di registrazione non è stata ancora completata: gli utenti in questo stato non possono accedere al sistema

Confermato

  il normale stato di un utente abilitato ad accedere al sistema